@@ -10,8 +10,8 @@
 #pragma once
 
 #include "akonadi_contact_widgets_private_export.h"
+#include "editor/widgets/contacteditorcombobox.h"
 #include <KContacts/PhoneNumber>
-#include <editor/widgets/contacteditorcombobox.h>
 namespace Akonadi
 {
 /**
@@ -42,7 +42,7 @@ public:
     /**
      * Returns the selected phone number type.
      */
-    KContacts::PhoneNumber::Type type() const;
+    [[nodiscard]] KContacts::PhoneNumber::Type type() const;
 
     void resetToDefault();
 
